package cn.wise.sc.cement.business.service.impl;

import cn.hutool.core.util.StrUtil;
import cn.wise.sc.cement.business.entity.SysUser;
import cn.wise.sc.cement.business.model.BaseResponse;
import cn.wise.sc.cement.business.model.LoginUser;
import cn.wise.sc.cement.business.service.ISysUserService;
import cn.wise.sc.cement.business.util.JwtUtil;
import cn.wise.sc.cement.business.util.MD5Util;
import cn.wise.sc.cement.business.util.RedisUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

@Service
public class LoginService {

    @Autowired
    private ISysUserService userService;
    @Autowired
    RedisUtil redisUtil;

    /**
     * 登录
     * @param userName
     * @param password
     * @return
     */
    public BaseResponse<String> login(String userName, String password) {
        if (StrUtil.isEmpty(userName)) {
            return BaseResponse.errorMsg("用户名为必填项!");
        }
        if (StrUtil.isEmpty(password)) {
            return BaseResponse.errorMsg("密码为必填项!");
        }
        System.out.println("=========userName==========password=========");
        System.out.println(userName + "\n" + password);
        try {
            QueryWrapper<SysUser> wrapper = new QueryWrapper<>();
            wrapper.eq("user_name", userName);
            SysUser sysUser = userService.getOne(wrapper);
            if (sysUser == null) {
                return BaseResponse.errorMsg("非系统用户不允许登录!");
            }
            if (sysUser.getStatus() == 0) {
                return BaseResponse.errorMsg("用户被禁用!");
            }
            if (sysUser.getIsDelete() == 0) {
                return BaseResponse.errorMsg("用户被删除!");
            }
            String loginPassWd = MD5Util.MD5Encode(password,"UTF-8");
            if (!sysUser.getPassWord().equals(loginPassWd)) {
                return BaseResponse.errorMsg("密码错误");
            }

            //生成token,存入redis
            String token = JwtUtil.createToken(sysUser.getId(), sysUser.getUserName(),
                    sysUser.getName(), sysUser.getPhone());
            System.out.println(token);
            redisUtil.setString(sysUser.getId().toString(), token, 3600);
            return BaseResponse.okData(token);
        } catch (Exception e) {
            return BaseResponse.errorMsg(e.getMessage());
        }
    }


    public static void main(String args[]){
        String loginPassWd = MD5Util.MD5Encode("123456","UTF-8");
        System.out.println(loginPassWd);
    }



    /**
     * 当前登录用户
     * @return
     */
    public BaseResponse<LoginUser> getLoginUser() {
        LoginUser loginUser = userService.getLoginUser();
        return BaseResponse.okData(loginUser);
    }





}
